TexFormatter
============

.. currentmodule:: stonerplots

.. autoclass:: TexFormatter
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TexFormatter.__call__
      ~TexFormatter.format_data
      ~TexFormatter.format_data_short

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: format_data
   .. automethod:: format_data_short
